@@ -13,9 +13,13 @@
    See the License for the specific language governing permissions and
    limitations under the License.
 """
-from .instruction import NavInsID, NavIns
+from .instruction import BaseNavInsID, NavInsID, NavIns
 from .navigator import Navigator
-from .stax_navigator import StaxNavigator
+from .touch_navigator import TouchNavigator
 from .nano_navigator import NanoNavigator
+from .navigation_scenario import NavigateWithScenario
 
-__all__ = ["NavInsID", "NavIns", "Navigator", "StaxNavigator", "NanoNavigator"]
+__all__ = [
+    "BaseNavInsID", "NavInsID", "NavIns", "Navigator", "TouchNavigator", "NanoNavigator",
+    "NavigateWithScenario"
+]
